==> GotoBLAS-1.10.tar.gz: GotoBLAS/common_level1.h <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#ifndef ASSEMBLER

float   sdot_k(long, float   *, long, float   *, long);
double  ddot_k(long, double  *, long, double  *, long);
xdouble qdot_k(long, xdouble *, long, xdouble *, long);

double dsdot_k (long, float  *,long,   float  *, long);
float  sdsdot_k(long, float   ,float *, long,  float *, long);

float   cdotc_k (long, float  *, long, float  *, long);
float   cdotu_k (long, float  *, long, float  *, long);
double  zdotc_k (long, double *, long, double *, long);
double  zdotu_k (long, double *, long, double *, long);
xdouble xdotc_k (long, xdouble *, long, xdouble *, long);
xdouble xdotu_k (long, xdouble *, long, xdouble *, long);

int    saxpy_k (long, long, long, float, 
	       float  *, long, float  *, long, float  *, long);
int    daxpy_k (long, long, long, double, 
	       double *, long, double *, long, double *, long);
int    qaxpy_k (long, long, long, xdouble, 
	       xdouble *, long, xdouble *, long, xdouble *, long);
int    caxpy_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float  *, long);
int    zaxpy_k (long, long, long, double, double,
	       double *, long, double *, long, double *, long);
int    xaxpy_k (long, long, long, xdouble, xdouble,
	       xdouble *, long, xdouble *, long, xdouble *, long);
int    caxpyc_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float  *, long);
int    zaxpyc_k (long, long, long, double, double,
	       double *, long, double *, long, double *, long);
int    xaxpyc_k (long, long, long, xdouble, xdouble,
	       xdouble *, long, xdouble *, long, xdouble *, long);

int    scopy_k(long, float  *, long, float  *, long);
int    dcopy_k(long, double *, long, double *, long);
int    qcopy_k(long, xdouble *, long, xdouble *, long);
int    ccopy_k(long, float  *, long, float  *, long);
int    zcopy_k(long, double *, long, double *, long);
int    xcopy_k(long, xdouble *, long, xdouble *, long);

int    sswap_k (long, long, long, float, 
	       float  *, long, float  *, long, float *, long);
int    dswap_k (long, long, long, double, 
	       double *, long, double *, long, double*, long);
int    qswap_k (long, long, long, xdouble, 
	       xdouble *, long, xdouble *, long, xdouble*, long);
int    cswap_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float *, long);
int    zswap_k (long, long, long, double, double,
	       double *, long, double *, long, double*, long);
int    xswap_k (long, long, long, xdouble, xdouble,
	       xdouble *, long, xdouble *, long, xdouble*, long);

float   sasum_k (long, float  *, long);
double  dasum_k (long, double *, long);
xdouble qasum_k (long, xdouble *, long);
float   scasum_k(long, float  *, long);
double  dzasum_k(long, double *, long);
xdouble qxasum_k(long, xdouble *, long);

float   samax_k (long, float  *, long);
double  damax_k (long, double *, long);
xdouble qamax_k (long, xdouble *, long);
float   scamax_k (long, float  *, long);
double  dzamax_k (long, double *, long);
xdouble qxamax_k (long, xdouble *, long);

float  samin_k (long, float  *, long);
double damin_k (long, double *, long);
float  camin_k (long, float  *, long);
double zamin_k (long, double *, long);

long   isamax_k(long, float  *, long);
long   idamax_k(long, double *, long);
long   iqamax_k(long, xdouble *, long);
long   icamax_k(long, float  *, long);
long   izamax_k(long, double *, long);
long   ixamax_k(long, xdouble *, long);

long   isamin_k(long, float  *, long);
long   idamin_k(long, double *, long);
long   iqamin_k(long, xdouble *, long);
long   icamin_k(long, float  *, long);
long   izamin_k(long, double *, long);
long   ixamin_k(long, xdouble *, long);

float  smax_k (long, float  *, long);
double dmax_k (long, double *, long);
xdouble qmax_k (long, xdouble *, long);
float  cmax_k (long, float  *, long);
double zmax_k (long, double *, long);
xdouble xmax_k (long, xdouble *, long);

float  smin_k (long, float  *, long);
double dmin_k (long, double *, long);
xdouble qmin_k (long, xdouble *, long);
float  cmin_k (long, float  *, long);
double zmin_k (long, double *, long);
xdouble xmin_k (long, xdouble *, long);

long   ismax_k(long, float  *, long);
long   idmax_k(long, double *, long);
long   iqmax_k(long, xdouble *, long);
long   icmax_k(long, float  *, long);
long   izmax_k(long, double *, long);
long   ixmax_k(long, xdouble *, long);

long   ismin_k(long, float  *, long);
long   idmin_k(long, double *, long);
long   iqmin_k(long, xdouble *, long);
long   icmin_k(long, float  *, long);
long   izmin_k(long, double *, long);
long   ixmin_k(long, xdouble *, long);

int    sscal_k(long, long, long, float, 
	      float *, long, float *, long,  float  *, long);
int    dscal_k(long, long, long, double, 
	      double *, long, double *, long,  double  *, long);
int    qscal_k(long, long, long, xdouble, 
	      xdouble *, long, xdouble *, long,  xdouble  *, long);
int    cscal_k(long, long, long, float, float,
	      float *, long, float *, long,  float  *, long);
int    zscal_k(long, long, long, double, double,
	      double *, long, double *, long,  double  *, long);
int    xscal_k(long, long, long, xdouble, xdouble,
	      xdouble *, long, xdouble *, long,  xdouble  *, long);
int    csscal_k(long, long, long, float, float,
	       float *, long, float *, long,  float  *, long);
int    zdscal_k(long, long, long, double, double,
	       double *, long, double *, long,  double  *, long);
int    xqscal_k(long, long, long, xdouble, xdouble,
	       xdouble *, long, xdouble *, long,  xdouble  *, long);

float  snrm2_k (long, float,  float  *, long);
double dnrm2_k (long, double, double *, long);
xdouble qnrm2_k (long, xdouble, xdouble *, long);
float  scnrm2_k(long, float,  float  *, long);
double dznrm2_k(long, double, double *, long);
xdouble qxnrm2_k(long, xdouble, xdouble *, long);

int    srot_k (long, float  *, long, float  *, long, float , float );
int    drot_k (long, double *, long, double *, long, double, double);
int    qrot_k (long, xdouble *, long, xdouble *, long, xdouble, xdouble);
int    csrot_k(long, float  *, long, float  *, long, float , float );
int    zdrot_k(long, double *, long, double *, long, double, double);
int    xdrot_k(long, xdouble *, long, xdouble *, long, xdouble, xdouble);

int    srotg_k(float  *, float  *, float  *, float  *);
int    drotg_k(double *, double *, double *, double *);
int    qrotg_k(xdouble *, xdouble *, xdouble *, xdouble *);
int    crotg_k(float  *, float  *, float  *, float  *);
int    zrotg_k(double *, double *, double *, double *);
int    xrotg_k(xdouble *, xdouble *, xdouble *, xdouble *);

int    srotmg_k(float  *, float  *, float  *, float  *, float  *);
int    drotmg_k(double *, double *, double *, double *, double *);
int    qrotmg_k(xdouble *, xdouble *, xdouble *, xdouble *, xdouble *);

int    srotm_k (long, float,  long, float,  long, float);
int    drotm_k (long, double, long, double, long, double);
int    qrotm_k (long, xdouble, long, xdouble, long, xdouble);

#ifdef XDOUBLE

#define DOT_K    qdot_k
#define ZDOTC_K  xdotc_k
#define ZDOTU_K  xdotu_k

#define SCAL_K   qscal_k
#define ZSCAL_K  xscal_k

#define SWAP_K   qswap_k
#define ZSWAP_K  xswap_k

#define AXPY_K	 qaxpy_k
#define ZAXPY_K  xaxpy_k
#define ZAXPYC_K  xaxpyc_k

#define  COPY_K  qcopy_k
#define ZCOPY_K  xcopy_k

#define IAMAX_K  iqamax_k
#define IZAMAX_K ixamax_k

#define IAMIN_K  iqamin_k
#define IZAMIN_K ixamin_k

#define ROT_K	 qrot_k
#define ZROT_K	 xrot_k

#elif defined(DOUBLE)

#define DOT_K    ddot_k
#define ZDOTC_K  zdotc_k
#define ZDOTU_K  zdotu_k

#define SCAL_K   dscal_k
#define ZSCAL_K  zscal_k

#define SWAP_K   dswap_k
#define ZSWAP_K  zswap_k

#define AXPY_K	 daxpy_k
#define ZAXPY_K  zaxpy_k
#define ZAXPYC_K  zaxpyc_k

#define  COPY_K  dcopy_k
#define ZCOPY_K  zcopy_k

#define IAMAX_K  idamax_k
#define IZAMAX_K izamax_k

#define IAMIN_K  idamin_k
#define IZAMIN_K izamin_k

#define ROT_K	 drot_k
#define ZROT_K	 zrot_k

#else

#define DOT_K    sdot_k
#define ZDOTC_K  cdotc_k
#define ZDOTU_K  cdotu_k

#define SCAL_K   sscal_k
#define ZSCAL_K  cscal_k

#define SWAP_K   sswap_k
#define ZSWAP_K  cswap_k

#define AXPY_K	 saxpy_k
#define ZAXPY_K  caxpy_k
#define ZAXPYC_K  caxpyc_k

#define  COPY_K   scopy_k
#define ZCOPY_K   ccopy_k

#define IAMAX_K   isamax_k
#define IZAMAX_K  icamax_k

#define IAMIN_K   isamin_k
#define IZAMIN_K  icamin_k

#define ROT_K	 srot_k
#define ZROT_K	 crot_k

#endif

#endif

==> GotoBLAS-1.19.tar.gz: GotoBLAS/common_level1.h <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#ifndef ASSEMBLER

float   sdot_k(long, float   *, long, float   *, long);
double  ddot_k(long, double  *, long, double  *, long);
xdouble qdot_k(long, xdouble *, long, xdouble *, long);

double dsdot_k (long, float  *,long,   float  *, long);
float  sdsdot_k(long, float   ,float *, long,  float *, long);

float   cdotc_k (long, float  *, long, float  *, long);
float   cdotu_k (long, float  *, long, float  *, long);
double  zdotc_k (long, double *, long, double *, long);
double  zdotu_k (long, double *, long, double *, long);
xdouble xdotc_k (long, xdouble *, long, xdouble *, long);
xdouble xdotu_k (long, xdouble *, long, xdouble *, long);

int    saxpy_k (long, long, long, float, 
	       float  *, long, float  *, long, float  *, long);
int    daxpy_k (long, long, long, double, 
	       double *, long, double *, long, double *, long);
int    qaxpy_k (long, long, long, xdouble, 
	       xdouble *, long, xdouble *, long, xdouble *, long);
int    caxpy_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float  *, long);
int    zaxpy_k (long, long, long, double, double,
	       double *, long, double *, long, double *, long);
int    xaxpy_k (long, long, long, xdouble, xdouble,
	       xdouble *, long, xdouble *, long, xdouble *, long);
int    caxpyc_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float  *, long);
int    zaxpyc_k (long, long, long, double, double,
	       double *, long, double *, long, double *, long);
int    xaxpyc_k (long, long, long, xdouble, xdouble,
	       xdouble *, long, xdouble *, long, xdouble *, long);

int    scopy_k(long, float  *, long, float  *, long);
int    dcopy_k(long, double *, long, double *, long);
int    qcopy_k(long, xdouble *, long, xdouble *, long);
int    ccopy_k(long, float  *, long, float  *, long);
int    zcopy_k(long, double *, long, double *, long);
int    xcopy_k(long, xdouble *, long, xdouble *, long);

int    sswap_k (long, long, long, float, 
	       float  *, long, float  *, long, float *, long);
int    dswap_k (long, long, long, double, 
	       double *, long, double *, long, double*, long);
int    qswap_k (long, long, long, xdouble, 
	       xdouble *, long, xdouble *, long, xdouble*, long);
int    cswap_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float *, long);
int    zswap_k (long, long, long, double, double,
	       double *, long, double *, long, double*, long);
int    xswap_k (long, long, long, xdouble, xdouble,
	       xdouble *, long, xdouble *, long, xdouble*, long);

float   sasum_k (long, float  *, long);
double  dasum_k (long, double *, long);
xdouble qasum_k (long, xdouble *, long);
float   scasum_k(long, float  *, long);
double  dzasum_k(long, double *, long);
xdouble qxasum_k(long, xdouble *, long);

float   samax_k (long, float  *, long);
double  damax_k (long, double *, long);
xdouble qamax_k (long, xdouble *, long);
float   scamax_k (long, float  *, long);
double  dzamax_k (long, double *, long);
xdouble qxamax_k (long, xdouble *, long);

float  samin_k (long, float  *, long);
double damin_k (long, double *, long);
float  camin_k (long, float  *, long);
double zamin_k (long, double *, long);

long   isamax_k(long, float  *, long);
long   idamax_k(long, double *, long);
long   iqamax_k(long, xdouble *, long);
long   icamax_k(long, float  *, long);
long   izamax_k(long, double *, long);
long   ixamax_k(long, xdouble *, long);

long   isamin_k(long, float  *, long);
long   idamin_k(long, double *, long);
long   iqamin_k(long, xdouble *, long);
long   icamin_k(long, float  *, long);
long   izamin_k(long, double *, long);
long   ixamin_k(long, xdouble *, long);

float  smax_k (long, float  *, long);
double dmax_k (long, double *, long);
xdouble qmax_k (long, xdouble *, long);
float  cmax_k (long, float  *, long);
double zmax_k (long, double *, long);
xdouble xmax_k (long, xdouble *, long);

float  smin_k (long, float  *, long);
double dmin_k (long, double *, long);
xdouble qmin_k (long, xdouble *, long);
float  cmin_k (long, float  *, long);
double zmin_k (long, double *, long);
xdouble xmin_k (long, xdouble *, long);

long   ismax_k(long, float  *, long);
long   idmax_k(long, double *, long);
long   iqmax_k(long, xdouble *, long);
long   icmax_k(long, float  *, long);
long   izmax_k(long, double *, long);
long   ixmax_k(long, xdouble *, long);

long   ismin_k(long, float  *, long);
long   idmin_k(long, double *, long);
long   iqmin_k(long, xdouble *, long);
long   icmin_k(long, float  *, long);
long   izmin_k(long, double *, long);
long   ixmin_k(long, xdouble *, long);

int    sscal_k(long, long, long, float, 
	      float *, long, float *, long,  float  *, long);
int    dscal_k(long, long, long, double, 
	      double *, long, double *, long,  double  *, long);
int    qscal_k(long, long, long, xdouble, 
	      xdouble *, long, xdouble *, long,  xdouble  *, long);
int    cscal_k(long, long, long, float, float,
	      float *, long, float *, long,  float  *, long);
int    zscal_k(long, long, long, double, double,
	      double *, long, double *, long,  double  *, long);
int    xscal_k(long, long, long, xdouble, xdouble,
	      xdouble *, long, xdouble *, long,  xdouble  *, long);
int    csscal_k(long, long, long, float, float,
	       float *, long, float *, long,  float  *, long);
int    zdscal_k(long, long, long, double, double,
	       double *, long, double *, long,  double  *, long);
int    xqscal_k(long, long, long, xdouble, xdouble,
	       xdouble *, long, xdouble *, long,  xdouble  *, long);

float  snrm2_k (long, float,  float  *, long);
double dnrm2_k (long, double, double *, long);
xdouble qnrm2_k (long, xdouble, xdouble *, long);
float  scnrm2_k(long, float,  float  *, long);
double dznrm2_k(long, double, double *, long);
xdouble qxnrm2_k(long, xdouble, xdouble *, long);

int    srot_k (long, float  *, long, float  *, long, float , float );
int    drot_k (long, double *, long, double *, long, double, double);
int    qrot_k (long, xdouble *, long, xdouble *, long, xdouble, xdouble);
int    csrot_k(long, float  *, long, float  *, long, float , float );
int    zdrot_k(long, double *, long, double *, long, double, double);
int    xqrot_k(long, xdouble *, long, xdouble *, long, xdouble, xdouble);

int    srotg_k(float  *, float  *, float  *, float  *);
int    drotg_k(double *, double *, double *, double *);
int    qrotg_k(xdouble *, xdouble *, xdouble *, xdouble *);
int    csrotg_k(float  *, float  *, float  *, float  *);
int    zdrotg_k(double *, double *, double *, double *);
int    xqrotg_k(xdouble *, xdouble *, xdouble *, xdouble *);

int    srotmg_k(float  *, float  *, float  *, float  *, float  *);
int    drotmg_k(double *, double *, double *, double *, double *);
int    qrotmg_k(xdouble *, xdouble *, xdouble *, xdouble *, xdouble *);

int    srotm_k (long, float,  long, float,  long, float);
int    drotm_k (long, double, long, double, long, double);
int    qrotm_k (long, xdouble, long, xdouble, long, xdouble);

#ifdef XDOUBLE

#define DOT_K    qdot_k
#define ZDOTC_K  xdotc_k
#define ZDOTU_K  xdotu_k

#define SCAL_K   qscal_k
#define ZSCAL_K  xscal_k

#define SWAP_K   qswap_k
#define ZSWAP_K  xswap_k

#define AXPY_K	 qaxpy_k
#define ZAXPY_K  xaxpy_k
#define ZAXPYC_K  xaxpyc_k

#define  COPY_K  qcopy_k
#define ZCOPY_K  xcopy_k

#define IAMAX_K  iqamax_k
#define IZAMAX_K ixamax_k

#define IAMIN_K  iqamin_k
#define IZAMIN_K ixamin_k

#define ROT_K	 qrot_k
#define ZROT_K	 xqrot_k

#elif defined(DOUBLE)

#define DOT_K    ddot_k
#define ZDOTC_K  zdotc_k
#define ZDOTU_K  zdotu_k

#define SCAL_K   dscal_k
#define ZSCAL_K  zscal_k

#define SWAP_K   dswap_k
#define ZSWAP_K  zswap_k

#define AXPY_K	 daxpy_k
#define ZAXPY_K  zaxpy_k
#define ZAXPYC_K  zaxpyc_k

#define  COPY_K  dcopy_k
#define ZCOPY_K  zcopy_k

#define IAMAX_K  idamax_k
#define IZAMAX_K izamax_k

#define IAMIN_K  idamin_k
#define IZAMIN_K izamin_k

#define ROT_K	 drot_k
#define ZROT_K	 zdrot_k

#else

#define DOT_K    sdot_k
#define ZDOTC_K  cdotc_k
#define ZDOTU_K  cdotu_k

#define SCAL_K   sscal_k
#define ZSCAL_K  cscal_k

#define SWAP_K   sswap_k
#define ZSWAP_K  cswap_k

#define AXPY_K	 saxpy_k
#define ZAXPY_K  caxpy_k
#define ZAXPYC_K  caxpyc_k

#define  COPY_K   scopy_k
#define ZCOPY_K   ccopy_k

#define IAMAX_K   isamax_k
#define IZAMAX_K  icamax_k

#define IAMIN_K   isamin_k
#define IZAMIN_K  icamin_k

#define ROT_K	 srot_k
#define ZROT_K	 csrot_k

#endif

#endif
